atomate.tools.post_process package — atomate 0.3 documentation

# atomate.tools.post_process package

## Submodules

## atomate.tools.post_process.gibbs module

Compute the quasi harmonic approximation gibbs free energy using phonopy.

`atomate.tools.post_process.gibbs.` `get_collection`(db_file)

  connect to the database and return task collection

`atomate.tools.post_process.gibbs.` `get_data`(db_file, query)

`atomate.tools.post_process.gibbs.` `get_db`(db_file)

  connect to the database and return the connection

`atomate.tools.post_process.gibbs.` `get_gibbs`(structure, db_file, eos='vinet', t_step=10, t_min=0, t_max=1000, mesh=(20, 20, 20), plot=False)

`atomate.tools.post_process.gibbs.` `get_phonopy`(structure)

## atomate.tools.post_process.plot_raman module

`atomate.tools.post_process.plot_raman.` `get_freq_intensities`(input_file)

  Return frequencies and normalized intensities from the json input file

  Args:
    input_file (str): path to the json file containing the raman tensors
  Returns:
    (numpy array, numpy array): frequencies, intensities

`atomate.tools.post_process.plot_raman.` `lorentzian`(w, wj, delta_w=4.0)

  delta function approximation

  Args:
    w (float/np.ndarray): frequency wj (float): frequency where the delta function will be centered delta_w (float): peak width, default= 4 cm^-1(from the above paper)
  Returns:
    broadened delta function

`atomate.tools.post_process.plot_raman.` `plot_spectrum`(freq, intensities, lorentzian_width)

  Plot the Raman spectrum.

  Args:
    freq (numpy array): frequencies intensities (numpy array): intensities computed from the raman tensors lorentzian_width (float): width of the lorentzian delta function

`atomate.tools.post_process.plot_raman.` `raman_intensity`(R)

  Scattering intensity

  Args:
    R (3x3 numpy array): Susceptibility tensor
  Returns:
    float: scattering intensity according to Eq 7, Phys Rev B 73, 104304 2006

`atomate.tools.post_process.plot_raman.` `run`()

## Module contents